==> haskell-trifecta-2-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 2
id: trifecta-2-5FSOgPxtTf69eZRQjUoI1E
key: trifecta-2-5FSOgPxtTf69eZRQjUoI1E
license: BSD-3-Clause
copyright: Copyright (C) 2010-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
abi: 987ab676b36858e0ae476ebee7399f69
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.Array
    Text.Trifecta.Util.IntervalMap Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
import-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
library-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/trifecta-2
hs-libraries: HStrifecta-2-5FSOgPxtTf69eZRQjUoI1E
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 array-0.5.3.0
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    charset-0.3.7.1-DMrgQHBkCY4BO4qp2JMLdy
    comonad-5.0.5-GxLjkJReVVVCdZ5ZrqdrbQ containers-0.6.0.1
    deepseq-1.4.4.0 fingertree-0.1.4.2-LeCTjI4pbvPGZmWHDe4eRB
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17.1-Dps0uj7PK1BKK4O2DnOjg0 mtl-2.2.2
    parsers-0.12.10-541kXjcFT8WAZuoEnVv4Fv
    profunctors-5.4-Hkj445FiweuBattm2piECo
    reducers-3.12.3-DdnocGKCXMvE1lEKrGyZ1N transformers-0.5.6.2
    unordered-containers-0.2.10.0-FCaPs5fnhYpFgvItTiMoQE
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-2-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 2
id: trifecta-2-8RqYG3dlGcF7YqHL0F5GjM
key: trifecta-2-8RqYG3dlGcF7YqHL0F5GjM
license: BSD-3-Clause
copyright: Copyright (C) 2010-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
abi: 7c33fc333acf12bbc37a3dc08e1c8403
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.Array
    Text.Trifecta.Util.IntervalMap Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
import-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
library-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/trifecta-2
hs-libraries: HStrifecta-2-8RqYG3dlGcF7YqHL0F5GjM
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    ansi-wl-pprint-0.6.9-37GARRLGI1c3EMKKxSVRl0 array-0.5.3.0
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-6PAyIvh6hy6Ilt6w0CbPFV
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    charset-0.3.7.1-9ZV0TbZwy5RLIki3sEQOLQ
    comonad-5.0.5-GxLjkJReVVVCdZ5ZrqdrbQ containers-0.6.0.1
    deepseq-1.4.4.0 fingertree-0.1.4.2-LeCTjI4pbvPGZmWHDe4eRB
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17.1-AfG7Jl0BIq5C3b1nEZHH8E mtl-2.2.2
    parsers-0.12.10-GdosIGswbE2Fya2n6eMQtp
    profunctors-5.4-Hkj445FiweuBattm2piECo
    reducers-3.12.3-2ROZozSUCJHPBvwIuqoEY transformers-0.5.6.2
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
